/**********************************************************************************************************************					
Instituto Nacional de Estadstica (INE) www.ine.es					
***********************************************************************************************************************					
					
DESCRIPCIN:					
Este programa genera un fichero SAS con formatos, partiendo de un fichero sin ellos.					
					
Consta de las siguientes partes:					
	* 1. Definir la librera de trabajo --> Libname				
	* 2. Definicin de formatos --> PROC FORMAT				
	* 3. Vincular formatos a la base de datos --> PASO data				
					
 Entrada:                                                           					
     - Fichero SAS sin formatos: 	 EPSH_2022.sas7bdat				
 Salida:                                                           					
     - Fichero SAS con formatos: 	 EPSH_2022_conFormato.sas7bdat				
					
Donde:					
	* Operacin: Encuesta de Personas sin Hogar
	* Periodo: 2022
					
************************************************************************************************************************/					
		
/* Directorio de trabajo para la operacin estadstica */
*%let siglas_periodo = EPSH_2022;
*%let conFormato = _conFormato;
					
/*1) Definir la librera de trabajo: introducir el directorio que desee como librera					
(se da como ejemplo 'C:\Mis resultados'), y copiar en ese directorio el fichero sas "EPSH_2022.sas7bdat"*/					
					
*libname ROutput 'C:\Mis resultados';	

options fmtsearch = (ROutput ROutput.cat1);

* 2) DEFINICIN DE FORMATOS;
PROC FORMAT LIBRARY=ROutput.cat1;

*TABLAS1;

value $TTpServ

"1"="Alojamiento"
"2"="Comida"
;
value $TNACIO

"1"="Espaola"
"2"="Extranjera"
"3"="Ambas"
;
value $T_2C

"1"="Todas las noches"
"2"="Ms de 2 veces por semana"
"3"="Entre 1 y 2 veces por semana"
"4"="De vez en cuando"
"5"="No ha dormido an all"
"9"="No sabe / No recuerda"
;
value $T_3C

"1"="No ha dormido an all"
"2"="Desde ayer"
"3"="Desde hace menos de una semana"
"4"="Hace ms de una semana y menos de un mes"
"5"="Hace ms de un mes y menos de tres meses"
"6"="Hace ms de tres meses y menos de un ao"
"7"="Hace ms de un ao y menos de cinco aos"
"8"="Hace ms de 5 aos"
"9"="No sabe / No recuerda"
;
value $T_7C

"1"="A medioda"
"2"="Por la noche"
"3"="A medioda y por la noche"
"9"="No sabe / No recuerda"
;
value $T_8C

"01"="No encontr un lugar donde pudiera comer"
"02"="El lugar donde podra haber comido estaba cerrado o fuera de servicio"
"03"="El lugar donde podra haber comido estaba completo o no quedaban plazas libres"
"04"="El lugar donde podra haber comido estaba lejos"
"05"="No saba que existieran lugares donde pudiera comer"
"06"="La comida no era buena"
"07"="No dispona de suficiente dinero para pagar la comida"
"08"="Estaba enfermo"
"09"="Haba comido algo en otro momento del da"
"10"="No tena hambre"
"11"="Otra razn"
"99"="No sabe / No recuerda"
;
value $T_11D

"1"="Una"
"2"="Dos"
"3"="Tres o cuatro"
"4"="Ms de cuatro"
;
value $T_12D

"1"="En litera"
"2"="Slo en una cama"
"3"="En un colchn en el suelo"
"4"="En el suelo directamente"
"5"="En una hamaca"
"6"="Compartiendo cama o colchn"
"7"="De otra forma"
;
value $T_13D

"1"="S"
"2"="No, es gratuito"
"3"="No, pero tiene que realizar un trabajo u otra actividad"
"9"="No sabe / No recuerda"
;
value $T_18D

"1"="En este centro"
"2"="En otro centro de atencin a personas sin hogar"
"3"="En casa de amigos"
"4"="Donde suele dormir o parar"
"5"="En casa de familiares"
"6"="En un lugar de culto (iglesia, mezquita, sinagoga, )"
"7"="En otro lugar"
"9"="No sabe / No recuerda"
;
value $T_115D

"1"="A travs de una asamblea"
"2"="Mediante un Buzn de sugerencias"
"3"="A travs del Comit de usuarios"
"9"="No sabe / No recuerda"
;
value $T_21D

"1"="No, es gratuito"
"2"="No, pero tiene que realizar un trabajo u otra actividad (curso, terapia,) para alojarse en l"
"3"="S, tiene que pagar una pequea cantidad"
"4"="No, se lo deja una persona de su familia"
"5"="No, se lo dejan unos amigos o conocidos"
"6"="No, es una vivienda desocupada"
"7"="Otro caso"
;
value $T_22D

"1"="A un organismo o una ong"
"2"="A la persona para la que trabaja"
"3"="A una persona que vive en el piso"
"4"="A una persona que no vive en el piso"
"5"="Otro caso"
;
value $T_23D

"1"="S, pero no ha hecho nada para que se marche"
"2"="S, ha tomado medidas legales"
"3"="S, ha tomado medidas policiales"
"4"="S, le ha amenazado con presiones y represalias"
"5"="No"
"9"="No sabe / No recuerda"
;
value $T_24D

"1"="No, se la facilita una administracin pblica, una ong u organismo"
"2"="No, pero tiene que realizar un trabajo u otra actividad (curso, terapia,)"
"3"="S, tiene que pagar una pequea cantidad"
"4"="No, se la facilita una persona de su familia"
"5"="No, se la facilitan unos amigos o conocidos"
"6"="Otro caso"
;
value $T1Cmunc

"1"="En ningn sitio (siempre las lleva consigo)"
"2"="Donde duerme"
"3"="En un centro de una administracin pblica, una ONG u organismo"
"4"="En casa de un familiar"
"5"="En casa de un/a amigo/a o conocido/a"
"6"="En otro lugar"
"9"="No sabe / No recuerda"
;
value $T2Cmunc

"1"="En un centro de una administracin pblica, una ONG u organismo"
"2"="En casa de amigos"
"3"="Donde suele dormir o parar"
"4"="En casa de familiares"
"5"="En un lugar de culto (iglesia, mezquita, sinagoga, )"
"6"="En otro lugar"
"9"="No sabe / No recuerda"
;
value $T3Cmunc

"1"="En un centro de una administracin pblica, una ONG u organismo"
"2"="En casa de amigos"
"3"="Donde suele dormir o parar"
"4"="En casa de familiares"
"5"="En un mvil que no es el suyo"
"6"="En otro lugar"
"9"="No sabe / No recuerda"
;
value $T_312D

"1"="No quiere dormir en los centros"
"2"="No saba que existieran esos centros"
"3"="El centro en el que quera dormir no tena plazas libres"
"4"="No ha podido ir al centro donde quiere dormir"
"5"="No hay ese tipo de centros en ese municipio"
"6"="No ha podido quedarse en el centro donde durmi antenoche"
"7"="Otras causas"
"9"="No sabe / No recuerda"
;
value $T_313D

"1"="No se fa de los que suelen estar all"
"2"="Hay mucho ruido"
"3"="Los dems residentes le molestan"
"4"="No puede ir con animales"
"5"="No le gusta su funcionamiento"
"6"="Otra razn"
"9"="No sabe / No recuerda"
;
value $T_2E

"1"="De 0 a 12 meses"
"2"="De 13 a 35 meses"
"3"="De 3 a 5 aos"
"4"="Ms de 5 aos"
;
value $T_3E

"1"="De 0 a 12 meses"
"2"="De 13 a 35 meses"
"3"="De 3 a 5 aos"
"4"="Ms de 5 aos"
"9"="No sabe / No recuerda"
;
value $T_5E

"1"="En este municipio"
"2"="En otro municipio"
"3"="En otro pas"
;
value $T_6E

"1"="S, en este municipio"
"2"="S, en otro municipio"
"3"="No"
;
value $T_7E

"1"="Por decisin personal"
"2"="Por dificultades administrativas"
"3"="Por otra razn"
"9"="No sabe / No recuerda"
;
value $T_2F

"1"="Menos de un mes"
"2"="Entre 1 y 6 meses"
"3"="De 6 a 12 meses"
"4"="Entre 1 y 3 aos"
"5"="Ms de 3 aos"
"9"="No sabe / No recuerda"
;
value $T_4F

"1"="No, solo"
"2"="S, con la ayuda de un familiar o amigo/a"
"3"="S, con la ayuda de un trabajador social"
"4"="S, con otra ayuda"
"9"="No sabe / No recuerda"
;
value $T_5F

"1"="A travs del ayuntamiento"
"2"="A travs de un organismo de servicios sociales"
"3"="A travs de una ONG"
"4"="A travs de un anuncio de prensa, de internet o de agencia inmobiliaria"
"5"="A travs de familiares o amigos"
"6"="A travs de una comunidad religiosa"
"7"="Otros"
"9"="No sabe / No recuerda"
;
value $T_6F

"1"="No dispone de dinero suficiente"
"2"="No quiere o no necesita buscar"
"3"="No sabe cmo hacerlo"
"4"="No cree que pueda encontrarlo"
"5"="No dispone de documentacin"
"6"="Por motivos de salud"
"7"="Por estar cumpliendo condena"
"8"="Otros"
"9"="No sabe / No recuerda"
;
value $T_2G

"1"="Con trabajo a tiempo parcial"
"2"="Con trabajo a tiempo completo"
"3"="Parado/a"
"4"="Estudiante"
"5"="Jubilado/a, retirado/a"
"6"="En situacin de invalidez"
"7"="Refugiado/a, solicitante de asilo"
"8"="Otras"
"9"="No sabe / No recuerda"
;
value $T_4G

"1"="Trabajaba por cuenta propia"
"2"="Para uno o diferentes particulares que le pagaban"
"3"="Para una empresa"
"4"="Para una administracin pblica"
"5"="Para una ong"
"6"="Para otro empleador"
"9"="No sabe / No recuerda"
;
value $T_5G

"1"="Menos de 1 mes"
"2"="De 1 a 6 meses"
"3"="De 7 a 24 meses"
"4"="Ms de 2 aos"
"9"="No sabe / No recuerda"
;
value $T_6G

"1"="A travs de la familia, amigos o conocidos"
"2"="A travs de una empresa"
"3"="A travs de un anuncio de peridico, en internet, en un tabln de anuncios, en una farola, en una parada de autobs, etc."
"4"="A travs de los servicios pblicos de empleo"
"5"="A travs de servicios sociales o una ONG"
"6"="Acudiendo a lugares en la calle donde se contrata personal"
"7"="Establecindose por su cuenta"
"8"="Por otro medio"
"9"="No sabe / No recuerda"
;
value $T_9G

"1"="Finaliz el contrato o termin la obra o servicio que realizaba"
"2"="Por una regulacin de empleo o cierre de la empresa"
"3"="Por despido"
"4"="Renunci al empleo por motivos de salud"
"5"="Renunci al empleo por tener que cuidar de la familia"
"6"="Renunci al empleo por otros motivos"
"7"="Otra razn"
"9"="No sabe / No recuerda"
;
value $T_12G

"1"="Hace menos de 6 meses"
"2"="Entre 6 y 12 meses"
"3"="Entre 1 y 3 aos"
"4"="Hace ms de 3 aos"
"9"="No sabe / No recuerda"
;
value $T_13G

"01"="Por motivos de salud"
"02"="Porque cree que a su edad ser difcil de encontrar"
"03"="Por tener que cuidar de la familia"
"04"="Por falta de formacin"
"05"="Por no creer que haya ofertas de trabajo para usted"
"06"="Porque no tiene papeles (no est autorizado para trabajar)"
"07"="Porque est de paso"
"08"="Porque est realizando un curso"
"09"="Porque no quiere trabajar"
"10"="Otra razn"
"99"="No sabe / No recuerda"
;
value $T_4H

"00"="No ha recibido dinero"
"01"="Dinero por su trabajo"
"02"="Dinero por la venta de objetos"
"03"="Dinero por la prestacin de servicios"
"04"="Renta Mnima de Insercin"
"05"="En el ltimo mes el informante ha recibido el Ingreso Mnimo de Insercin"
"06"="Prestacin por desempleo"
"07"="Ayuda de emergencia"
"08"="Pensin de invalidez"
"09"="Pensin de jubilacin"
"10"="Pensin de viudedad"
"11"="Pensin no contributiva"
"12"="Otra prestacin"
"13"="Dinero de un familiar"
"14"="Dinero de un amigo/a o conocido/a"
"15"="Dinero de gente de la calle"
"16"="Dinero de una ONG"
"17"="Dinero de otros"
"99"="No sabe / No recuerda"
;
value $T_6H

"01"="Comida"
"02"="Bebida"
"03"="Alojamiento"
"04"="Ropa, vestir"
"05"="Transportes, viajes"
"06"="Diversiones"
"07"="Entrega o enva a casa"
"08"="Medicamentos"
"09"="Tabaco"
"10"="Telfono y/o internet"
"11"="Higiene"
"12"="Otros"
"88"="Sin gastos"
"89"="Sin ms gastos"
"99"="No sabe / No recuerda"
;
value $T_8H

"1"="Un banco o entidad financiera"
"2"="La administracin (hacienda, etc)"
"3"="Una tienda, supermercado, etc"
"4"="Un particular (propietario/a del piso, etc)"
"5"="Un amigo/a"
"6"="Un familiar"
"9"="No sabe / No recuerda"
;
value $T_10H

"1"="A un banco o entidad financiera"
"2"="A una ONG"
"3"="A la familia"
"4"="A los amigos"
"5"="A otros"
"9"="No sabe / No recuerda"
;
value $T_1I

"Z"="No sabe leer o escribir (analfabetos)"
"A"="Estudios primarios incompletos (ha asistido menos de 5 aos a la escuela)"
"B"="Educacin primaria"
"C"="Primera etapa de educacin secundaria sin ttulo de graduado en ESO y similar (EGB, Bachillerato elemental)"
"D"="Primera etapa de educacin secundaria con ttulo de graduado en ESO y equivalentes (EGB, Bachillerato elemental)"
"E"="Certificados de profesionalidad de nivel 1 o nivel 2 y similares (garanta Social, PCPI)"
"F"="Bachillerato y similares (BUP, COU, PREU)"
"G"="Enseanzas de formacin profesional, artes plsticas y diseo y deportivas de grado medio y similares"
"H"="Enseanzas profesionales de msica y danza y similares. Certificado de escuelas oficiales de idiomas de nivel avanzado y similar. Formacin Profesional Bsica (FPB)"
"I"="Certificados de profesionalidad de nivel 3; programas de corta duracin que requieren segunda etapa de secundaria y similares"
"J"="Enseanzas de formacin profesional, artes plsticas y diseo y deportivas de grado superior y equivalentes. Ttulos propios universitarios que precisan del ttulo de bachiller, de duracin igual o superior a dos aos"
"K"="Grados universitarios de 240 crditos ECTS y equivalentes. Diplomados universitarios y equivalentes. Ttulos propios universitarios de experto o especialista, de menos de 60 crditos ECTS para titulados universitarios"
"L"="Grados universitarios de ms de 240 crditos ECTS y equivalentes. Licenciados y equivalentes"
"M"="Msteres oficiales universitarios y equivalentes. Especialidades en Ciencias de la Salud por el sistema de residencia y similares. Ttulos propios universitarios de mster (maestras), de 60 o ms crditos ECTS para titulados universitarios"
"N"="Doctorado universitario"
"9"="No sabe/No contesta"
;
value $T_1J

"1"="Muy bueno"
"2"="Bueno"
"3"="Regular"
"4"="Malo"
"5"="Muy malo"
"9"="No sabe/No contesta"
;
value $T_5J

"1"="Por decisin personal"
"2"="Por dificultades administrativas"
"3"="Por otra razn"
"9"="No sabe/No contesta"
;
value $T_7J

"1"="Enfermedades del sistema circulatorio"
"2"="Enfermedades del aparato respiratorio y del aparato digestivo"
"3"="Enfermedades endocrinas/ metablicas y de los rganos de los sentidos"
"4"="Enfermedades del sistema osteo-mioarticular"
"5"="Trastornos mentales"
"6"="Otras enfermedades"
"9"="No sabe/No contesta"
;
value $T_10J

"1"="Se ha contagiado y ha estado hospitalizado"
"2"="Se ha contagiado y ha estado en aislamiento"
"3"="Posiblemente se ha contagiado pero no le han hecho test"
"4"="No ha tenido sntomas y cree que no se ha contagiado"
"5"="No sabe si se ha contagiado pero ha hecho cuarentena por contacto con contagiados"
"9"="No sabe/No contesta"
;
value $T_11J

"1"="En un centro de una administracin pblica, una ONG u organismo"
"2"="Donde suele dormir o parar"
"3"="En casa de familiares"
"4"="En casa de amigos"
"5"="En otro lugar"
"9"="No sabe/No contesta"
;
value $T_12J

"1"="S"
"2"="No, porque no le han avisado"
"3"="No, porque ha rechazado vacunarse"
"4"="No, por otro motivo"
"9"="No sabe/No contesta"
;
value $TSEVERI

"1"="Ninguna"
"2"="Leve"
"3"="Moderada"
"4"="Moderadamente Grave"
"5"="Grave"
"9"="No consta"
;
value $TPREVAL

"1"="Cuadro depresivo mayor"
"2"="Otros cuadros depresivos"
"3"="Sin cuadro depresivo alguno"
"9"="No consta"
;
value $T_17J

"1"="S, fuma diariamente"
"2"="S, fuma, pero no diariamente"
"3"="No fuma actualmente, pero ha fumado antes"
"4"="No fuma, ni ha fumado nunca de manera habitual"
"9"="No sabe/No contesta"
;
value $T_18J

"1"="Diariamente"
"2"="De 4 a 6 das a la semana"
"3"="De 2 a 3 das a la semana"
"4"="1 da a la semana"
"5"="1 da cada 2 semanas"
"6"="1 da al mes"
"7"="Menos de 1 da al mes"
"8"="Menos de una vez al ao"
"9"="No sabe/No contesta"
;
value $TConAlc

"0"="Sin consumo"
"1"="Consumo ligero"
"2"="Consumo moderado"
"3"="Consumo alto"
"4"="Consumo excesivo"
"9"="No consta"
;
value $T_3K

"1"="Soltero/a"
"2"="Casado/a"
"3"="Viudo/a"
"4"="Separado/a legalmente"
"5"="Divorciado/a"
"9"="No sabe/No contesta"
;
value $T_9K

"1"="En el ltimo mes"
"2"="En el ltimo ao"
"3"="Sin contacto"
"9"="No sabe/No contesta"
;
value $T_10K

"1"="Con su familia (padres, hermanos)"
"2"="Con su madre"
"3"="Con su padre"
"4"="Con sus abuelos"
"5"="Con otros familiares"
"6"="Con otras personas no familiares"
"7"="En una institucin de acogida"
"9"="No sabe/No contesta"
;
value $T_2L

"1"="Por iniciativa propia"
"2"="En la calle"
"3"="A travs de los servicios sociales pblicos"
"4"="Por medio de una ONG"
"5"="Por medio de un familiar"
"6"="Por medio de un amigo o conocido"
"7"="Por una decisin judicial"
"8"="Otro medio"
"9"="No sabe/No contesta"
;
value $T_4L

"01"="Una vivienda o una habitacin"
"02"="Un trabajo"
"03"="Una prestacin econmica"
"04"="Una red de apoyo"
"05"="Formacin y/u orientacin laboral"
"06"="Asistencia en un centro como interno/a"
"07"="Dejar el consumo de sustancias"
"08"="Tener documentacin en regla"
"09"="Mejorar o mantener la salud"
"10"="Otra cosa"
"99"="No sabe/No contesta"
;
value $T_5L

"1"="Nada"
"2"="Poco"
"3"="Bastante"
"4"="Mucho"
"9"="No sabe/No contesta"
;
value $T_8L

"1"="Sus ingresos son superiores a los que se establecen para cobrarla"
"2"="Su situacin familiar ha cambiado"
"3"="No cumple con el tiempo mnimo de constitucin de la unidad familiar o de convivencia"
"4"="Ha cambiado de lugar de residencia"
"5"="Cobra otro subsidio"
"6"="Tiene trabajo"
"7"="Acab el plazo o agot la prestacin"
"8"="Otras"
"9"="No sabe / No recuerda"
;
value $T_10L

"1"="Desconoca su existencia"
"2"="No est interesado/a en la prestacin"
"3"="Cree que no cumple los requisitos"
"4"="Otros"
"9"="No sabe / No recuerda"
;
value $T_1M

"1"="Nunca"
"2"="Algunas veces"
"3"="Muchas veces"
"4"="Constantemente"
"9"="No sabe / No recuerda"
;
value $T_4M

"1"="No saba cmo hacerlo"
"2"="No sirve para nada"
"3"="Por su situacin legal"
"4"="Por miedo a represalias"
"5"="Por otro motivo"
"9"="No sabe / No recuerda"
;
value $T_5M

"1"="S, una vez"
"2"="S, varias veces"
"3"="No"
"9"="No sabe / No recuerda"
;
value $T_7M

"1"="Abogado de los servicios sociales"
"2"="Abogado facilitado por una ONG"
"3"="Abogado contratado personalmente"
"4"="Abogado correspondiente al turno de oficio"
"5"="No tuvo asistencia"
"9"="No sabe / No recuerda"
;
value $T_8M

"1"="S, por un juzgado de menores"
"2"="S, por otros juzgados o tribunales"
"3"="S, por ambos tipos de juzgados o tribunales"
"4"="No"
"9"="No sabe / No recuerda"
;
value $T_9M

"1"="S, una sola vez"
"2"="S, ms de una vez"
"3"="No"
"9"="No sabe / No recuerda"
;
value $T_10M

"1"="S, cumpliendo condena"
"2"="S, esperando a ser juzgado/a"
"3"="No"
"9"="No sabe / No recuerda"
;

*TABLAS2;
value $TSiNo

"1"="S"
"6"="No"
"9"="No sabe / No recuerda"
;
value $TSEXO

"1"="Hombre"
"6"="Mujer"
;
value $TCCAA

"01"="Andaluca"
"02"="Aragn"
"03"="Asturias, Principado de"
"04"="Balears, Illes"
"05"="Canarias"
"06"="Cantabria"
"07"="Castilla y Len"
"08"="Castilla-La Mancha"
"09"="Catalua"
"10"="Comunitat Valenciana"
"11"="Extremadura"
"12"="Galicia"
"13"="Madrid, Comunidad de"
"14"="Murcia, Regin de"
"15"="Navarra, Comunidad Foral de"
"16"="Pas Vasco"
"17"="Rioja, La"
"18"="Ceuta"
"19"="Melilla"
"99"="No sabe / No recuerda"
;
value $TCntnnt

"1"="Unin Europea"
"2"="Resto de Europa"
"3"="Africa"
"4"="Amrica"
"5"="Asia"
"6"="Oceana"
"9"="No sabe / No recuerda"
;
value $TLgrAlj

"11"="Albergue, residencia o centro de acogida"
"12"="Centro de acogida a mujeres vctimas de violencia de gnero"
"13"="Centro de ayuda al refugiado y centros para demandantes de asilo"
"14"="Centros de internamiento de inmigrantes"
"15"="Hospitales y centros sanitarios"
"16"="Prisiones"
"17"="Centros para personas mayores"
"21"="Piso facilitado por una administracin pblica, una ONG u organismo (incluye el piso pagado por la persona que recibe la renta mnima de insercin o el Ingreso Mnimo Vital)"
"22"="Piso alquilado por la persona (excluye el piso pagado por la persona que recibe la renta mnima de insercin o el Ingreso Mnimo Vital)"
"23"="Piso ocupado"
"24"="Piso de su propiedad"
"25"="Alojado en casa de un familiar o amigo"
"31"="Pensin pagada por una ONG u organismo (incluye la pensin pagada por la persona que recibe la renta mnima de insercin o el Ingreso Mnimo Vital)"
"32"="Pensin pagada por la persona (exluye la pensin pagada por la persona que recibe la renta mnima de insercin o el Ingreso Mnimo Vital)"
"41"="En espacio pblico (estacin de ferrocarril, estacin de autobuses, metro, aparcamiento, jardn pblico, descampado)"
"42"="Alojamientos de fortuna (hall del inmueble, cueva, coche)"
"99"="No sabe / No recuerda"
;
value $TLgrCmd

"1"="Comida en un comedor o restaurante social, del lugar donde duerme"
"2"="Comida en un comedor o restaurante social, excepto del lugar en el que duerme"
"3"="Comida en casa de familiares o amigos"
"4"="Comida cocinada en casa del informante"
"5"="Comida comprada (en un bar, cafetera, supermercado o solicitada a servicios de cmida rpida)"
"6"="Alimentos donados por particulares"
"7"="Alimentos recuperados"
"8"="Otros"
"9"="No sabe / No recuerda"
"0"="No ha comido"
;
value $TpCmunc

"1"="En este centro"
"2"="En casa de amigos"
"3"="Donde suele dormir o parar"
"4"="En casa de familiares"
"5"="En un mvil que no es el suyo"
"6"="En otro lugar"
"9"="No sabe / No recuerda"
;
value $TpMail

"01"="En su mvil"
"02"="En un mvil que no es el suyo"
"03"="En este centro"
"04"="En un locutorio"
"05"="En una biblioteca"
"06"="En casa de amigos"
"07"="Donde suele dormir o parar"
"08"="En casa de familiares"
"09"="En otro lugar"
"99"="No sabe / No recuerda"
;
value $Tp2CmD

"1"="En este centro"
"2"="En casa de amigos"
"3"="Donde suele dormir o parar"
"4"="En casa de familiares"
"5"="En un mvil que no es el suyo"
"6"="En otro lugar"
"9"="No sabe / No recuerda"
;
value $Tp2WbD

"01"="En su mvil"
"02"="En un mvil que no es el suyo"
"03"="En un centro de una administracin pblica, una ONG u organismo"
"04"="En un locutorio"
"05"="En una biblioteca"
"06"="En casa de amigos"
"07"="Donde suele dormir o parar"
"08"="En casa de familiares"
"09"="En otro lugar"
"99"="No sabe / No recuerda"
;
value $TLgrN

"1"="Espaa"
"2"="Resto de Unin Europea"
"3"="Resto de Europa"
"4"="frica"
"5"="Amrica"
"6"="Asia"
"7"="Oceana"
"9"="No sabe / No recuerda"
;
value $TOcupac

"00"="Ocupaciones militares"
"01"="Directores y gerentes"
"02"="Tcnicos y profesionales cientficos e intelectuales"
"03"="Tcnicos, profesionales de apoyo"
"04"="Empleados contables, administrativos y otros empleados de oficina"
"05"="Trabajadores de los servicios de restauracin, personales, proteccin y vendedores"
"06"="Trabajadores cualificados en el sector agrcola, ganadero, forestal y pesquero."
"07"="Artesanos y trabajadores cualificados de las industrias manufactureras y la construccin (excepto operadores de instalaciones y maquinaria)"
"08"="Operadores de instalaciones y maquinaria, y montadores"
"09"="Ocupaciones elementales"
"99"="No sabe / No recuerda"
;
value $TLngs

"01"="Espaol"
"02"="Cataln"
"03"="Valenciano"
"04"="Vasco"
"05"="Gallego"
"06"="Francs"
"07"="Ingls"
"08"="Portugus"
"09"="Rumano"
"10"="rabe"
"11"="Otros idiomas europeos"
"12"="Otros idiomas africanos"
"13"="Idiomas americanos"
"14"="Idiomas asiticos"
"15"="Otros idiomas"
;
value $TOLngs

"01"="Espaol"
"02"="Cataln"
"03"="Valenciano"
"04"="Vasco"
"05"="Gallego"
"06"="Francs"
"07"="Ingls"
"08"="Portugus"
"09"="Rumano"
"10"="rabe"
"11"="Otros idiomas europeos"
"12"="Otros idiomas africanos"
"13"="Idiomas americanos"
"14"="Idiomas asiticos"
"15"="Otros idiomas"
"99"="No sabe / No recuerda"
;

*TABLAS3;
value NYrs

88="Toda la vida, desde siempre"
99="No sabe / No recuerda"
;
value N_2DIG
99="No sabe / No recuerda"
;
value N_3DIG
999="No sabe / No recuerda"
;
value N_4DIG
9999="No sabe / No recuerda"
;


* 3) VINCULAR FORMATOS A LA BASE DE DATOS;

	DATA ROutput.&siglas_periodo.&conFormato;
		set ROutput.&siglas_periodo;

FORMAT CCAA $TCCAA.;
FORMAT A1_5 $TTpServ.;

FORMAT B1 $TSEXO.;
FORMAT B3 $TNACIO.;
FORMAT B3_LIT_COD $TCntnnt.;

FORMAT C1_1 $TLgrAlj.;
FORMAT C2 $T_2C.;
FORMAT C3 $T_3C.;
FORMAT C4_1 $TLgrAlj.;
FORMAT C4_2 $TLgrAlj.;
FORMAT C4_3 $TLgrAlj.;
FORMAT C4_4 $TLgrAlj.;
FORMAT C4_5 $TLgrAlj.;
FORMAT C4_6 $TLgrAlj.;
FORMAT C4_7 $TLgrAlj.;
FORMAT PERNOCTA $TLgrAlj.;

FORMAT C5_1a $TLgrCmd.;
FORMAT C5_2a $TLgrCmd.;
FORMAT C5_3a $TLgrCmd.;
FORMAT C5_4a $TLgrCmd.;
FORMAT C5_5a $TLgrCmd.;
FORMAT C5_6a $TLgrCmd.;
FORMAT C5_7a $TLgrCmd.;
FORMAT C5_1b $TLgrCmd.;
FORMAT C5_2b $TLgrCmd.;
FORMAT C5_3b $TLgrCmd.;
FORMAT C5_4b $TLgrCmd.;
FORMAT C5_5b $TLgrCmd.;
FORMAT C5_6b $TLgrCmd.;
FORMAT C5_7b $TLgrCmd.;
FORMAT C6 $TSiNo.;
FORMAT C7 $T_7C.;
FORMAT C8 $T_8C.;
FORMAT D1_1 $T_11D.;
FORMAT D1_2 $T_12D.;
FORMAT D1_3 $T_13D.;
FORMAT D1_4 $TSiNo.;
FORMAT D1_5 $T_13D.;
FORMAT D1_6 $TSiNo.;
FORMAT D1_7 $TSiNo.;
FORMAT D1_8 $T_18D.;
FORMAT D1_9 $TSiNo.;
FORMAT D1_10 $TSiNo.;
FORMAT D1_11 $TpCmunc.;
FORMAT D1_12 $TSiNo.;
FORMAT D1_13 $TpMail.;
FORMAT D1_14 $TSiNo.;
FORMAT D1_15 $T_115D.;
FORMAT D2_1 $T_21D.;
FORMAT D2_2 $T_22D.;
FORMAT D2_3 $T_23D.;
FORMAT D2_4 $T_24D.;
FORMAT D2_5_1 $TSiNo.;
FORMAT D2_5_2 $TSiNo.;
FORMAT D2_5_3 $TSiNo.;
FORMAT D2_5_4 $TSiNo.;
FORMAT D2_5_5 $TSiNo.;
FORMAT D2_5_6 $TSiNo.;
FORMAT D2_5_7 $TSiNo.;
FORMAT D2_5_8 $TSiNo.;
FORMAT D2_5_9 $TSiNo.;
FORMAT D2_5_10 $TSiNo.;
FORMAT D2_6 $TSiNo.;
FORMAT D2_7 $TSiNo.;
FORMAT D2_8 $Tp2CmD.;
FORMAT D2_9 $TSiNo.;
FORMAT D2_10 $Tp2WbD.;
FORMAT D3_1 $TSiNo.;
FORMAT D3_2 $T1Cmunc.;
FORMAT D3_3 $TSiNo.;
FORMAT D3_4 $T2Cmunc.;
FORMAT D3_5 $TSiNo.;
FORMAT D3_6 $TSiNo.;
FORMAT D3_7 $T3Cmunc.;
FORMAT D3_8 $TSiNo.;
FORMAT D3_9 $Tp2WbD.;
FORMAT D3_10_1_1 $TSiNo.;
FORMAT D3_10_1_2 $TSiNo.;
FORMAT D3_10_1_3 $TSiNo.;
FORMAT D3_10_2_1 $TSiNo.;
FORMAT D3_10_2_2 $TSiNo.;
FORMAT D3_10_2_3 $TSiNo.;
FORMAT D3_11_1 $TSiNo.;
FORMAT D3_11_2 $TSiNo.;
FORMAT D3_11_3 $TSiNo.;
FORMAT D3_11_4 $TSiNo.;
FORMAT D3_11_5 $TSiNo.;
FORMAT D3_11_6 $TSiNo.;
FORMAT D3_11_7 $TSiNo.;
FORMAT D3_11_8 $TSiNo.;
FORMAT D3_12 $T_312D.;
FORMAT D3_13 $T_313D.;
FORMAT PAIS_NAC $TLgrN.;
FORMAT E2_A NYrs.;

FORMAT T_RESID $T_2E.;
FORMAT E3_A NYrs.;

FORMAT T_RESCCAA $T_3E.;
FORMAT E4 $TCCAA.;
FORMAT E5 $T_5E.;
FORMAT E6 $T_6E.;
FORMAT E7 $T_7E.;
FORMAT E8 $TSiNo.;
FORMAT LNG_MAT $TLngs.;
FORMAT E10 $TSiNo.;
FORMAT IDIOMA_1 $TOLngs.;
FORMAT IDIOMA_2 $TOLngs.;
FORMAT IDIOMA_3 $TOLngs.;
FORMAT PAIS_PA $TLgrN.;
FORMAT PAIS_MA $TLgrN.;
FORMAT F1_1 $TSiNo.;
FORMAT F1_2 $TSiNo.;
FORMAT F1_3 $TSiNo.;
FORMAT F1_4 $TSiNo.;
FORMAT F1_5 $TSiNo.;
FORMAT F1_6 $TSiNo.;
FORMAT F1_7 $TSiNo.;
FORMAT F1_8 $TSiNo.;
FORMAT F1_9 $TSiNo.;
FORMAT F1_10 $TSiNo.;
FORMAT F1_11 $TSiNo.;
FORMAT F1_12 $TSiNo.;
FORMAT F1_13 $TSiNo.;
FORMAT F1_14 $TSiNo.;
FORMAT F1_15 $TSiNo.;
FORMAT F2 $T_2F.;
FORMAT F3 $TSiNo.;
FORMAT F4 $T_4F.;
FORMAT F5_1 $T_5F.;
FORMAT F5_2 $T_5F.;
FORMAT F6 $T_6F.;
FORMAT G1 $TSiNo.;
FORMAT G2 $T_2G.;
FORMAT G3 $TOcupac.;
FORMAT G4 $T_4G.;
FORMAT G5_R $T_5G.;
FORMAT G6_1 $T_6G.;
FORMAT G6_2 $T_6G.;
FORMAT G7 $TSiNo.;
FORMAT G8 $TOcupac.;
FORMAT G9 $T_9G.;
FORMAT G10 $TSiNo.;
FORMAT G11_1 $TSiNo.;
FORMAT G11_2 $TSiNo.;
FORMAT G11_3 $TSiNo.;
FORMAT G11_4 $TSiNo.;
FORMAT G11_5 $TSiNo.;
FORMAT G11_6 $TSiNo.;
FORMAT G11_7 $TSiNo.;
FORMAT G11_8 $TSiNo.;
FORMAT G12 $T_12G.;
FORMAT G13_1 $T_13G.;
FORMAT G13_2 $T_13G.;
FORMAT H1_1 $TSiNo.;
FORMAT H1_2 $TSiNo.;
FORMAT H1_3 $TSiNo.;
FORMAT H2_4 $TSiNo.;
FORMAT H2_5 $TSiNo.;
FORMAT H2_6 $TSiNo.;
FORMAT H2_7 $TSiNo.;
FORMAT H2_8 $TSiNo.;
FORMAT H2_9 $TSiNo.;
FORMAT H2_10 $TSiNo.;
FORMAT H2_11 $TSiNo.;
FORMAT H2_12 $TSiNo.;
FORMAT H3_13 $TSiNo.;
FORMAT H3_14 $TSiNo.;
FORMAT H3_15 $TSiNo.;
FORMAT H3_16 $TSiNo.;
FORMAT H3_17 $TSiNo.;
FORMAT H4 $T_4H.;
FORMAT H5 N_4DIG.;
FORMAT H6_1 $T_6H.;
FORMAT H6_2 $T_6H.;
FORMAT H7 $TSiNo.;
FORMAT H8_1 $T_8H.;
FORMAT H8_2 $T_8H.;
FORMAT H9 $TSiNo.;
FORMAT H10_1 $T_10H.;
FORMAT H10_2 $T_10H.;
FORMAT I1 $T_1I.;
FORMAT I2 N_2DIG.;
FORMAT I3_1 $TSiNo.;
FORMAT I3_2 $TSiNo.;
FORMAT I3_3 $TSiNo.;
FORMAT I4 $TSiNo.;
FORMAT J1 $T_1J.;
FORMAT J2 $TSiNo.;
FORMAT J3 N_2DIG.;
FORMAT J4 $TSiNo.;
FORMAT J5 $T_5J.;
FORMAT J6 $TSiNo.;
FORMAT J7_1 $T_7J.;
FORMAT J7_2 $T_7J.;
FORMAT J8 $TSiNo.;
FORMAT J9 $TSiNo.;
FORMAT J10 $T_10J.;
FORMAT J11 $T_11J.;
FORMAT J12 $T_12J.;
FORMAT SEV_DEPR $TSEVERI.;
FORMAT CUAD_DEPR $TPREVAL.;
FORMAT J14 $TSiNo.;
FORMAT J15 N_3DIG.;
FORMAT J16_1 $TSiNo.;
FORMAT J16_2 $TSiNo.;
FORMAT J16_3 $TSiNo.;
FORMAT J16_4 $TSiNo.;
FORMAT J17 $T_17J.;
FORMAT J18_1 $T_18J.;
FORMAT J18_2 $T_18J.;
FORMAT J19_1 N_2DIG.;
FORMAT J19_2 N_2DIG.;
FORMAT CONSAL_TOTAL N_4DIG.;
FORMAT CONS_ALCOHOL $TConAlc.;
FORMAT J20 $TSiNo.;
FORMAT J21 $TSiNo.;
FORMAT J22_1 $TSiNo.;
FORMAT J22_2 $TSiNo.;
FORMAT J22_3 $TSiNo.;
FORMAT J22_4 $TSiNo.;
FORMAT J23 $TSiNo.;
FORMAT K1 $TSiNo.;
FORMAT K2 $TSiNo.;
FORMAT K3 $T_3K.;
FORMAT K4 $TSiNo.;
FORMAT K5 N_2DIG.;
FORMAT K6 $TSiNo.;
FORMAT K7_1 $TSiNo.;
FORMAT K7_2 $TSiNo.;
FORMAT K7_3 $TSiNo.;
FORMAT K7_4 $TSiNo.;
FORMAT K7_5 $TSiNo.;
FORMAT K7_6 $TSiNo.;
FORMAT K7_7 $TSiNo.;
FORMAT K7_8 $TSiNo.;
FORMAT K7_9 $TSiNo.;
FORMAT K7_10 $TSiNo.;
FORMAT K8 $TSiNo.;
FORMAT K9_1 $T_9K.;
FORMAT K9_2 $T_9K.;
FORMAT K9_3 $T_9K.;
FORMAT K9_4 $T_9K.;
FORMAT K9_5 $T_9K.;
FORMAT K9_6 $T_9K.;
FORMAT K9_7 $T_9K.;
FORMAT K10 $T_10K.;
FORMAT K11_1 $TSiNo.;
FORMAT K11_2 $TSiNo.;
FORMAT K11_3 $TSiNo.;
FORMAT K11_4 $TSiNo.;
FORMAT K11_5 $TSiNo.;
FORMAT K11_6 $TSiNo.;
FORMAT K11_7 $TSiNo.;
FORMAT K11_8 $TSiNo.;
FORMAT K11_9 $TSiNo.;
FORMAT K11_10 $TSiNo.;
FORMAT K11_11 $TSiNo.;
FORMAT K11_12 $TSiNo.;
FORMAT K11_13 $TSiNo.;
FORMAT L1 $TSiNo.;
FORMAT L2 $T_2L.;
FORMAT L3_1_1 $TSiNo.;
FORMAT L3_1_2 $TSiNo.;
FORMAT L3_2_1 $TSiNo.;
FORMAT L3_2_2 $TSiNo.;
FORMAT L3_3_1 $TSiNo.;
FORMAT L3_3_2 $TSiNo.;
FORMAT L3_4_1 $TSiNo.;
FORMAT L3_4_2 $TSiNo.;
FORMAT L3_5_1 $TSiNo.;
FORMAT L3_5_2 $TSiNo.;
FORMAT L3_6_1 $TSiNo.;
FORMAT L3_6_2 $TSiNo.;
FORMAT L3_7_1 $TSiNo.;
FORMAT L3_7_2 $TSiNo.;
FORMAT L3_8_1 $TSiNo.;
FORMAT L3_8_2 $TSiNo.;
FORMAT L3_9_1 $TSiNo.;
FORMAT L3_9_2 $TSiNo.;
FORMAT L4_1 $T_4L.;
FORMAT L4_2 $T_4L.;
FORMAT L4_3 $T_4L.;
FORMAT L5 $T_5L.;
FORMAT L6 $TSiNo.;
FORMAT L7 $TSiNo.;
FORMAT L8_1 $T_8L.;
FORMAT L8_2 $T_8L.;
FORMAT L9 $TSiNo.;
FORMAT L10 $T_10L.;
FORMAT M1 $T_1M.;
FORMAT M2_1 $TSiNo.;
FORMAT M2_2 $TSiNo.;
FORMAT M2_3 $TSiNo.;
FORMAT M2_4 $TSiNo.;
FORMAT M2_5 $TSiNo.;
FORMAT M2_6 $TSiNo.;
FORMAT M3 $TSiNo.;
FORMAT M4 $T_4M.;
FORMAT M5 $T_5M.;
FORMAT M6 $T_5M.;
FORMAT M7 $T_7M.;
FORMAT M8 $T_8M.;
FORMAT M9 $T_9M.;
FORMAT M10 $T_10M.;
FORMAT M11 $TSiNo.;
FORMAT M12_1_1 $TSiNo.;
FORMAT M12_1_2 $TSiNo.;
FORMAT M12_2_1 $TSiNo.;
FORMAT M12_2_2 $TSiNo.;
FORMAT M12_3_1 $TSiNo.;
FORMAT M12_3_2 $TSiNo.;
FORMAT M12_4_1 $TSiNo.;
FORMAT M12_4_2 $TSiNo.;
FORMAT M13_1 $TSiNo.;
FORMAT M13_2 $TSiNo.;
FORMAT M13_3 $TSiNo.;
FORMAT M13_4 $TSiNo.;



RUN;
/* FIN PROGRAMA: Microdatos en SAS: EPSH_2022.sas*/
